//======================================================== IBJdmn.h
//
// Data Manager for IBJ-programs
// =============================
//
// Copyright (C) Dr. Lutz Janicke, Dunum, Germany, 1999-2000
// email: lj@janicke.de
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// history:
//
// last change: 98-07-31  lj
// 2000-07-27 uj  extended for IBJodor
//
//==================================================================
#ifndef  IBJDMN_INCLUDE
#define  IBJDMN_INCLUDE

#ifndef   IBJARY_INCLUDE
#include  "IBJary.h"
#endif

#ifndef   IBJTXT_INCLUDE
#include  "IBJtxt.h"
#endif

extern char *DmnVersion;

void DmnReplaceEscape(  // replace ansi escape codes
char *s )               // source and destination string
;

char *DmnFindName(  // Find a parameter name in the header
char *buf,      // header (lines separated by \n)
char *name )    // parameter name
  ;         // RETURN: pointer to name string

char *DmnGetValues(   // Get the value string of a parameter
char *hdr,        // header
char *name,       // name of the prameter
int *pl )       // set to length of the value string
  ;           // RETURN: pointer to value string

int DmnRplValues(     // Replace the value string of a parameter
TXTSTR *phdr,       // header
char *name,       // name of the parameter
char *values )      // new values (or NULL)
;           // RETURN: 0 = replaced or deleted, 1 = added

int DmnGetCount(  // Get the number of tokens of a parameter
char *hdr,      // header
char *name )    // name of the parameter
;         // RETURN: number of tokens for this parameter

int DmnGetInt(    // Get integer values of a parameter
char *hdr,      // header
char *name,     // name of the parameter
char *frm,      // format for reading
int *ii,      // integer vector
int n )       // maximum number of positions in ii[]
;         // RETURN: number of values read

int DmnPutInt(    // Put integer values of a parameter into header
char *hdr,      // header
int len,      // maximum length of header string
char *name,     // name of the parameter
char *frm,      // format for writing (with separator!)
int *ii,      // integer vector
int n )       // number of values to write
;         // RETURN: number of values written

int DmnGetFloat(  // Get float values of a parameter
char *hdr,      // header
char *name,     // name of the parameter
char *frm,      // format for reading
float *ff,      // float vector
int n )       // maximum number of positions in ff[]
;         // RETURN: number of values read

int DmnPutFloat(  // Put float values of a parameter into header
char *hdr,      // header
int len,      // maximum length of header string
char *name,     // name of the parameter
char *frm,      // format for writing (with separator!)
float *ff,      // float vector
int n )       // number of values to write
;         // RETURN: number of values written

int DmnGetString(   // Get string values of a parameter
char *hdr,      // header
char *name,     // name of the parameter
char **ss,      // string vector
int n )       // maximum number of positions in ss[]
;         // RETURN: number of values read

int DmnPutString(   // Write string values of a parameter into header
char *hdr,      // header
int len,      // maximum length of header string
char *name,     // name of the parameter
char *frm,      // format for writing (with separator and \"...\" !)
char **ss,      // string vector
int n )       // number of strings to write
;         // RETURN: number of strings written

int DmnWrite(     // Write data into a file
char *fn,     // file name (with path, without extension)
char *hdr,      // header string
ARYDSC *pa )    // address of array descriptor
;
int DmnRead(    // Read data from a file
char *fn,     // file name (with path, without extension)
TXTSTR *pu,     // user header text
TXTSTR *ps,     // system header text
ARYDSC *pa )    // address of array descriptor
;

#endif  /*#################################################################*/
